from annotell.input_api.model.base_serializer import BaseSerializer


class InitializedInput(BaseSerializer):
    scene_uuid: str
